@@ -1,11 +1,12 @@
-#!/usr/bin/env pyhton3
+#!/usr/bin/env python3
 # -*- coding: utf-8, vim: expandtab:ts=4 -*-
 
-from webarticlecurator.utils import Logger, wrap_input_consants, DummyConverter
+from webarticlecurator.logger import Logger
+from webarticlecurator.utils import wrap_input_constants, DummyConverter
 from webarticlecurator.enhanced_downloader import WarcCachingDownloader, sample_warc_by_urls, validate_warc_file, \
     online_test
 from webarticlecurator.news_crawler import NewsArchiveCrawler, NewsArticleCrawler
 from webarticlecurator.version import __version__
 
 __all__ = ['NewsArchiveCrawler', 'NewsArticleCrawler', 'DummyConverter', 'WarcCachingDownloader', 'sample_warc_by_urls',
-           'validate_warc_file', 'online_test', 'Logger', 'wrap_input_consants', __version__]
+           'validate_warc_file', 'online_test', 'Logger', 'wrap_input_constants', __version__]
