@@ -16,7 +16,7 @@ from warcio.exceptions import ArchiveLoadFailed
 from requests import Session
 from urllib.parse import urlparse, quote, urlunparse
 from requests.exceptions import RequestException
-from urllib3.exceptions import ProtocolError, InsecureRequestWarning
+from urllib3.exceptions import ProtocolError, InsecureRequestWarning, LocationParseError
 from urllib3 import disable_warnings
 from chardet import detect
 from ratelimit import limits, sleep_and_retry
@@ -257,7 +257,8 @@ class WarcDownloader:
 
         try:  # The actual request (on the reparsed URL, everything else is made on the original URL)
             resp = self._requests_get(url_reparsed, headers=self._req_headers, stream=True, verify=self._verify_request)
-        except (UnicodeError, RequestException) as err:  # UnicodeError is originated from idna codec error
+        # UnicodeError is originated from idna codec error, LocationParseError is originated from URLlib3 error
+        except (UnicodeError, RequestException, LocationParseError) as err:
             self._handle_request_exception(url, 'RequestException happened during downloading: {0} \n\n'
                                                 ' The program ignores it and jumps to the next one.'.format(err))
             return None
@@ -370,7 +371,7 @@ class WarcReader:
             # and https://github.com/webrecorder/warcio/issues/91
             self.info_record_data = dict(r.split(': ', maxsplit=1) for r in custom_headers_raw.decode('UTF-8')
                                          .strip().split('\r\n') if len(r) > 0)
-        except (UnicodeDecodeError, ValueError) as e:
+        except ValueError as e:
             if self._strict_mode:
                 raise e
             self._logger.log('WARNING', 'WARCINFO record in', self._stream.name,
@@ -457,16 +458,19 @@ def sample_warc_by_urls(source_warcfiles, new_urls, sampler_logger, target_warcf
     for url in new_urls:
         url = url.strip()
         sampler_logger.log('INFO', 'Adding url', url)
-        cont = w.download_url(url)
-        if is_out_dir_mode and cont is not None:
-            safe_url = ''.join(char if char.isalnum() else '_' for char in url).rstrip('_')[:200]
-            i, fname = 0, os.path.join(out_dir, '{0}{1}.html'.format(safe_url, 0))
-            while os.path.exists(fname):
-                i += 1
-                fname = os.path.join(out_dir, '{0}{1}.html'.format(safe_url, i))
-            sampler_logger.log('INFO', 'Creating file', fname)
-            with open(fname, 'w', encoding='UTF-8') as fh:
-                fh.write(cont)
+        if not offline or url in w.url_index:
+            cont = w.download_url(url)
+            if is_out_dir_mode and cont is not None:
+                safe_url = ''.join(char if char.isalnum() else '_' for char in url).rstrip('_')[:200]
+                i, fname = 0, os.path.join(out_dir, '{0}{1}.html'.format(safe_url, 0))
+                while os.path.exists(fname):
+                    i += 1
+                    fname = os.path.join(out_dir, '{0}{1}.html'.format(safe_url, i))
+                sampler_logger.log('INFO', 'Creating file', fname)
+                with open(fname, 'w', encoding='UTF-8') as fh:
+                    fh.write(cont)
+        else:
+            sampler_logger.log('ERROR', 'URL not present in archive', url)
 
 
 def validate_warc_file(source_warcfiles, validator_logger):
